// inject-interceptor.js

(function () {
  const TARGET_URL_PART = 'api/user/items/search';

   // ✅ 向 content.js 发送数据
  function sendToContentScript(type, data) {
    window.postMessage({
      source: 'inject-script',
      type,
      payload: data
    }, '*');
  }

  // =========================
  // ✅ fetch 拦截器
  // =========================
  const originalFetch = window.fetch;
  window.fetch = async function (...args) {
    const url = args[0];
    const options = args[1] || {};
    const method = (options.method || 'GET').toUpperCase();

    if (typeof url === 'string' && url.includes(TARGET_URL_PART)) {
      console.log("[fetch拦截]", method, url);

      const response = await originalFetch.apply(this, args);
      const clone = response.clone();
      clone.text().then(text => {
        console.log("[fetch响应]", text);
      });

      return response;
    }

    return originalFetch.apply(this, args);
  };

  // =========================
  // ✅ XMLHttpRequest 拦截器
  // =========================
  const OriginalXHR = window.XMLHttpRequest;

  function CustomXHR() {
    const xhr = new OriginalXHR();

    let _url = "";
    let _method = "";

    const open = xhr.open;
    xhr.open = function (method, url, ...rest) {
      _method = method;
      _url = url;
      return open.call(xhr, method, url, ...rest);
    };

    const send = xhr.send;
    xhr.send = function (body) {
      if (_url.includes(TARGET_URL_PART)) {
        xhr.addEventListener('readystatechange', function () {
          if (xhr.readyState === 4) {
            console.log("[XHR拦截]", _method, _url);
            console.log("[XHR请求体]", body);
            console.log("[XHR响应]", xhr.responseText);
            try {
              const jsonResponse = JSON.parse(xhr.responseText); // 转换为 JSON
              console.log("[XHR响应 JSON]", jsonResponse);
              sendToContentScript('XHR_DATA', {
                method: _method,
                url: _url,
                requestBody: body || null,
                response: jsonResponse,
                handle:'extract_search_shangjias'
              });
            } catch (e) {
              console.error("[XHR响应 JSON 解析错误]", e);
            }
          }
        });
      }
      return send.call(xhr, body);
    };

    return xhr;
  }

  window.XMLHttpRequest = CustomXHR;

  console.log("✅ fetch + XHR 拦截器已注入页面环境");
})();
